@@ -375,7 +375,7 @@ ee_filesel_cb_select(GtkWidget * widget, gpointer * data)
   GtkWidget          *w, *f, *a, *c, *b, *om, *q, *p;
   gchar              *ext, *file, *file2, tmp[1024], *curfile;
   GdkImlibImage      *im = NULL;
-  gint                ww, hh, preview;
+  gint                ww, hh, preview, i;
   GdkPixmap          *pmap = NULL, *mask = NULL;
   time_t              t;
 
@@ -399,7 +399,7 @@ ee_filesel_cb_select(GtkWidget * widget, gpointer * data)
       if (curfile)
 	g_free(curfile);
 
-      gtk_object_set_data(GTK_OBJECT(w), "filename", (gpointer)strdup(file));
+      gtk_object_set_data(GTK_OBJECT(w), "filename", (gpointer)g_strdup(file));
 
       ext = extension(file);
       if ((!g_strcasecmp(ext, "ppm")) ||
@@ -477,15 +477,28 @@ ee_filesel_cb_select(GtkWidget * widget, gpointer * data)
 	      gdk_window_shape_combine_mask(a->window, mask, 0, 0);
 	      gdk_imlib_free_pixmap(pmap);
 	    }
+	  t = moddate(file);
+	  file2 = ctime(&t);
+	  gtk_clist_set_text(GTK_CLIST(c), 5, 1, file2);
+	  i = filesize(file);
+	  if (i > 0)
+	    {
+	      i = i >> 10;
+	      /* If it's > 0, better show 1k than 0k */
+	      if (i == 0)
+		i = 1;
+	    }
+	  g_snprintf(tmp, sizeof(tmp), "%i kb", i);
+	  gtk_clist_set_text(GTK_CLIST(c), 3, 1, tmp);
+	}
+      else
+	{
+	  gtk_clist_set_text(GTK_CLIST(c), 3, 1, "");
+	  gtk_clist_set_text(GTK_CLIST(c), 5, 1, "");
 	}
       file2 = fullfileof(file);
       gtk_clist_set_text(GTK_CLIST(c), 0, 1, file2);
       g_free(file2);
-      g_snprintf(tmp, sizeof(tmp), "%i kb", filesize(file) >> 10);
-      gtk_clist_set_text(GTK_CLIST(c), 3, 1, tmp);
-      t = moddate(file);
-      file2 = ctime(&t);
-      gtk_clist_set_text(GTK_CLIST(c), 5, 1, file2);
     }
   if (!preview)
     return;
@@ -789,7 +802,6 @@ ee_filesel_new(void)
   gtk_widget_show(hh);
   gtk_box_pack_start(GTK_BOX(v), hh, FALSE, FALSE, 0);
 
-  l = gtk_label_new(_("Scaling Factor:"));
   l = gtk_label_new(_("Scaling Factor:"));
   gtk_widget_show(l);
   gtk_box_pack_start(GTK_BOX(hh), l, FALSE, FALSE, 0);
